# Generated by Django 2.2.4 on 2019-08-14 08:15

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DynamicConfig',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(max_length=32, unique=True, verbose_name='Key')),
                ('value', models.TextField(verbose_name='Value')),
                ('value_type', models.CharField(choices=[('int', 'Int'), ('float', 'Float'), ('str', 'String'), ('bool', 'Boolean'), ('json', 'JSON')], max_length=12, verbose_name='Value Type')),
                ('is_show', models.BooleanField(default=True, verbose_name='Whether the API returns.')),
                ('desc', models.CharField(max_length=128, null=True, verbose_name='Description about this field')),
            ],
        ),
    ]
